﻿using Infragistics.Windows.DataPresenter;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DataGridFieldLayoutAssignment
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        ObservableCollection<GridSampleData> Data { get; set; }

        public MainWindow()
        {
            InitializeComponent();
            this.Loaded += MainWindow_Loaded;
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            // setup grid settings
            DataGrid.FieldLayoutSettings.AutoGenerateFields = false;
            DataGrid.FieldLayoutSettings.AllowAddNew = false;
            DataGrid.FieldLayoutSettings.AllowDelete = false;
            DataGrid.FieldLayoutSettings.ExpansionIndicatorDisplayMode = ExpansionIndicatorDisplayMode.CheckOnDisplay;
            DataGrid.FieldLayoutSettings.FixedFieldUIType = FixedFieldUIType.None;
            DataGrid.FieldLayoutSettings.SelectionTypeRecord = Infragistics.Windows.Controls.SelectionType.Default;

            // create the field layouts
            CreateFieldLayouts();
            DataGrid.AssigningFieldLayoutToItem += DataGrid_AssigningFieldLayoutToItem;

            // assign the data
            Data = new ObservableCollection<GridSampleData>();
            Data.Add(new GridSampleData { Children = new ObservableCollection<GridSampleData>(), Status = "parent row", });
            Data[0].Children.Add(new GridSampleData { Children = new ObservableCollection<GridSampleData>(), Status = "child row", });
            Data[0].Children[0].Children.Add(new GridSampleData { Status = "child child row" });

            DataGrid.DataSource = Data;
        }

        void DataGrid_AssigningFieldLayoutToItem(object sender, Infragistics.Windows.DataPresenter.Events.AssigningFieldLayoutToItemEventArgs e)
        {
            if (e.ParentExpandableFieldRecord == null)
                e.FieldLayout = DataGrid.FieldLayouts["parentLayout"];
            else
                e.FieldLayout = DataGrid.FieldLayouts["childLayout"];
        }

        void CreateFieldLayouts()
        {
            FieldLayout parentLayout = new FieldLayout() { Key = "parentLayout" };
            parentLayout.Fields.Add(new Field { Name = "Status" });
            parentLayout.Fields.Add(new Field { Name = "CurveName" });
            parentLayout.Fields.Add(new Field { Name = "LastUpdate" });
            parentLayout.Fields.Add(new Field { Name = "Children" });
            DataGrid.FieldLayouts.Add(parentLayout);

            FieldLayout childLayout = new FieldLayout() { Key = "childLayout" };
            childLayout.Settings.LabelLocation = LabelLocation.Hidden;
            childLayout.Fields.Add(new Field { Name = "Status" });
            childLayout.Fields.Add(new Field { Name = "CurveName" });
            childLayout.Fields.Add(new Field { Name = "LastUpdate" });
            childLayout.Fields.Add(new Field { Name = "Children" });
            DataGrid.FieldLayouts.Add(childLayout);
        }
    }

    // for simplicity I'll define the columns like so:
    public class GridSampleData
    {
        public string Status { get; set; }
        public string CurveName { get; set; }
        public string LastUpdate { get; set; }

        // this will produce the scenario where the grid will automatically use the same
        // FieldLayout for each level.
        public ObservableCollection<GridSampleData> Children { get; set; }
    }
}
